#------------------------------------------------------------------------------

# MIT License

# Copyright (c) 2020 Landcare Research New Zealand Ltd

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#------------------------------------------------------------------------------

# Python 3.5.5 | packaged by conda-forge | (default, Jul 24 2018, 01:52:17) [MSC v.1900 64 bit (AMD64)] on win32
import sys
sys.path.insert(0, "../")
from nlmpy import nlmpy # version 0.1.5
import numpy as np # version 1.14.2
import matplotlib as mpl # version 2.0.2
from mpl_toolkits.axes_grid1 import make_axes_locatable

#------------------------------------------------------------------------------

np.random.seed(1)

# Specify the raster metadata
xMin = 10
yMin = 10
nRow = 120
nCol = 100
cellSize = 0.1

#------------------------------------------------------------------------------
# Plot figures
#------------------------------------------------------------------------------

# Specify some plotting stuff
extent = [xMin, xMin + (nCol * cellSize), yMin, yMin + (nRow * cellSize)]
# Check if LaTeX is installed to plot with consistent math font
from distutils.spawn import find_executable
if find_executable('latex'):
    mpl.pyplot.rc('text', usetex=True)
# If a LaTeX error is raised, the preceding 3 lines of code can be removed to
# reproduce figures with slightly different fonts or you could try adding
# mpl.pyplot.rcParams['text.usetex'] = False if on Matplotlib version >=3.x
mpl.pyplot.rc('font', family='serif', size=8)

#------------------------------------------------------------------------------
# Plot neutral landscape models
#------------------------------------------------------------------------------

hs = [0.0, 1.0, 2.0]
captions = ["(a)", "(b)", "(c)"]

fig, axs = mpl.pyplot.subplots(nrows=1, ncols=3, 
                               figsize=(6, 3)) # figsize=(width, height) in inches

def plotNLM(ax, h, caption, legend=True):
    ax.set_title(caption)
    im = ax.imshow(nlmpy.mpd(nRow, nCol, h=h), interpolation='none', extent=extent, vmin=0, vmax=1,
                   cmap=mpl.cm.YlOrRd)
    ax.xaxis.set_ticks([])
    ax.yaxis.set_ticks([])
    divider = make_axes_locatable(ax)
    if legend == True:
        cax = divider.append_axes("bottom", size="4%", pad=0.25)
        cbar = fig.colorbar(im, ax=ax, orientation='horizontal', cax=cax, ticks=[0.0, 0.5, 1.0])
        cbar.set_label("Value " + r"$(z)$")

for i in [0,1,2]:
    plotNLM(axs[i], hs[i], captions[i])

mpl.pyplot.tight_layout(pad=0.5)
mpl.pyplot.savefig('figure-4.png', dpi=300)

#------------------------------------------------------------------------------